import sys
import csv
import numpy as np
import re
from nltk.sentiment.vader import SentimentIntensityAnalyzer as SIA
import datetime
#take in title and text

def removeNewline(string):
    #jank regex to remove newlines from text
    i = 0
    for char in string:
        if char == "\n":
            string = string[:i] + string[i+1:]
            if i > 0: i -= 1
        i += 1
    return string

def copGenderAge(titlestr):
    #default return will be male male 30 30 if we can't find anything
    #male -1, female -2
    #ages are encoded as integer values
    titlestr = titlestr.replace(",", " ")
    #this list is our default value
    L = [-1,30,-1,30]
    extracted = re.findall(r'(?<=\()\w+(?=\))|(?<=\[)\w+(?=\])|(?<={)\w+('
                              r'?=})',titlestr)
    if len(extracted) < 2: return L
    R = []
    def convertSex(sexstr):
        if sexstr == 'M' or sexstr == 'm':
            return -1
        if sexstr == 'F' or sexstr == 'f':
            return -2

    for agesex in extracted:
        age = re.findall('\d+',agesex)
        sex = re.findall(r'm|f|M|F',agesex)
        sex_convert = list(map(convertSex,sex))
        # print(age)
        # print(sex_convert)
        if len(age) > 0: R.extend(age)
        if len(sex_convert)>0: R.extend(sex_convert)
    if len(R) != 4: return L
    return R

def generateSentScores(text):
    #function generates+returns the top five scores of each word
    #as well as the overall average of the scores
    #could edit this part to provide a set # of data points
    #or just output more data
    sia = SIA()
    L = []
    lines = re.split("[.!?]",text)
    for line in lines:
        polarity = sia.polarity_scores(line)['compound']
        L.append(polarity)
    J = np.sort(np.absolute(L))[::-1][0:5]
    K = np.sort(L)
    results = [L[list(np.absolute(L)).index(i)] for i in J]
    results.append(sia.polarity_scores(text)['compound'])
    return results, K

def listToText(list):
    #transforms a list into a string
    s = ""
    for val in list:
        s = s + str(val) + " "
    return s + "\n"

def main():
    assert(len(sys.argv) == 6)
    #opening/setting up files
    titles = open(sys.argv[1])
    texts = open(sys.argv[2])
    present = datetime.datetime.now().strftime("%Y-%m-%d %H-%M") #str in
    # y/m/d and then h/min format
    title_enc = open(sys.argv[3].split(".")[0] + '-' + present + ".csv",
                     "w+")
    text_scores = open(sys.argv[4].split(".")[0] +'-' + present + ".csv",
                                                      "w+")
    every_word_score = open(sys.argv[5].split(".")[0] + '-' + present +
                            ".csv", "w+")
    text_seperator = " ------------TEXT START ----------- "
    #render titles into list
    titlelist = [title for title in titles]
    #stick body texts of posts into list
    newstr = ""
    textlist = []
    for val in texts:
        if text_seperator in val and newstr != "" and newstr != "\n":
            textlist.append(newstr.replace("\n",""))
            newstr = ""
        else: newstr = newstr + val
    titlevec_writer = csv.writer(title_enc,delimiter = ',')
    score_writer = csv.writer(text_scores,delimiter = ',')
    ews_writer =  csv.writer(every_word_score,delimiter = ',')
    for title,text in list(zip(titlelist,textlist)):
        title_vec = copGenderAge(title)
        senti,overall = generateSentScores(text)
        titlevec_writer.writerow(title_vec)
        #this multiplication is needed to preserve accuracy
        #gets unmultiplied later within max
        score_writer.writerow(senti)
        ews_writer.writerow(overall)

    return

main()